==> mcp_server_say_hello-0.1.1.tar.gz: mcp_server_say_hello-0.1.1/README.md <==
# mcp_server_say_hello

MCP Protocol-compliant greeting service providing standardized greeting tool interfaces.

## Features

- Personalized greeting generation
- Compliant with MCP v1.2 protocol specifications
- Multi-environment deployment support (uvx/docker/pip)
- Complete tool registration specifications

## Tool Registration

### Tool List

1. `say_hello`
   - Description: Greeting tool for users
   - Input Parameters:
  
     ```json
     {
       "name": "username"
     }
     ```

   - Success Response:
  
     ```json
     {
       "type": "text",
       "text": "Hello {username}!"
     }
     ```

## Installation

### Using UVX (Recommended)

```bash
uvx install mcp_server_say_hello
```

### Using pip

```bash
# for production use (default)
pip install mcp_server_say_hello

# for development local use
pip install -e .

# 启动服务
python -m mcp_server_say_hello
```

## API Reference

**endpoint**: POST /say_hello

request parameters:

```json
{
  "name": "username"
}
```

success response:

```json
{
  "message": "Hello {username}!"
}
```

## Integrated configuration

### VS Code configuration

```json
{
  "mcp": {
    "servers": {
      "say_hello": {
        "command": "uvx",
        "args": ["mcp_server_say_hello"]
      }
    }
  }
}
```

or locally (if you installed the package using `pip install` or `pip install -e .`):

```json
{
  "mcp": {
    "servers": {
      "say_hello": {
        "command": "/path/to/python", // python bin path or "python" if you have it in your PATH
        "args": ["-m", "mcp_server_say_hello"]
      }
    }
  }
}
```

### Claude Desktop or Trae CN Desktop configuration

```json
{
  "mcpServers": {
    "say_hello": {
      "command": "python",
      "args": ["-m", "mcp_server_say_hello"]
    }
  }
}
```

## debug

Debug the service using the MCP protocol inspector:

```bash
npx @modelcontextprotocol/inspector uvx mcp_server_say_hello
```

==> mcp_server_say_hello-0.1.2.tar.gz: mcp_server_say_hello-0.1.2/README.md <==
# mcp_server_say_hello

MCP Protocol-compliant greeting service providing standardized greeting tool interfaces.

## Features

- Personalized greeting generation
- Compliant with MCP v1.2 protocol specifications
- Multi-environment deployment support (uvx/docker/pip)
- Complete tool registration specifications

## Tool Registration

### Tool List

1. `say_hello`
   - Description: Greeting tool for users
   - Input Parameters:
  
     ```json
     {
       "name": "username"
     }
     ```

   - Success Response:
  
     ```json
     {
       "type": "text",
       "text": "Hello {username}!"
     }
     ```

## API Reference

**endpoint**: POST /say_hello

request parameters:

```json
{
  "name": "username"
}
```

success response:

```json
{
  "message": "Hello {username}!"
}
```

## Integrated configuration

### VS Code configuration

```json
{
  "mcp": {
    "servers": {
      "say_hello": {
        "command": "uvx",
        "args": ["mcp_server_say_hello"]
      }
    }
  }
}
```

or locally (if you installed the package using `pip install` or `pip install -e .`):

```json
{
  "mcp": {
    "servers": {
      "say_hello": {
        "command": "/path/to/python",
        "args": ["-m", "mcp_server_say_hello"]
      }
    }
  }
}
```

### Claude Desktop or Trae CN Desktop configuration

use python

```json
{
  "mcpServers": {
    "say_hello": {
      "command": "python",
      "args": ["-m", "mcp_server_say_hello"]
    }
  }
}
```

or uvx

```json
{
  "mcpServers": {
    "say_hello": {
      "command": "uvx",
      "args": ["mcp_server_say_hello"]
    }
  }
}
```

## debug

Debug the service using the MCP protocol inspector:

```bash
npx @modelcontextprotocol/inspector uvx mcp_server_say_hello
```
